Index: chrome/browser/browser_window.h |
=================================================================== |
--- chrome/browser/browser_window.h (revision 30544) |
+++ chrome/browser/browser_window.h (working copy) |
@@ -205,8 +205,8 @@ |
// Shows the repost form confirmation dialog box. |
virtual void ShowRepostFormWarningDialog(TabContents* tab_contents) = 0; |
- // Shows a dialog to the user that the history is too new. |
- virtual void ShowHistoryTooNewDialog() = 0; |
+ // Shows a dialog to the user that something is wrong with the profile. |
brettw
2009/10/30 21:52:43
Can you document the parameter here?
|
+ virtual void ShowProfileErrorDialog(int message) = 0; |
// Show the bubble that indicates to the user that a theme is being installed. |
virtual void ShowThemeInstallBubble() = 0; |